@@ -16,5 +16,9 @@ public:
 	 * then return the original rights back.
 	 */
 	static int open(const char *name);
+
+	static bool copy(int source, int dest);
+
+	static bool isZeroOnly(const char *buf, size_t size);
 };
 
