@@ -6,8 +6,8 @@
 
 #include <sys/types.h>
 
-#define PARENT_MEMORY Compress
-//#define PARENT_MEMORY File
+typedef Compress PARENT_MEMORY;
+//typedef File PARENT_MEMORY;
 
 /**
  * Class Memory represents memory backed file. It caches any writes to
@@ -16,18 +16,24 @@
  */
 class Memory : public PARENT_MEMORY
 {
-	friend ostream &operator<<(ostream &os, const Memory &rMemory);
-
+private:
 	typedef PARENT_MEMORY Parent;
 
-	int write_block(bool force);
+	int write(bool force);
 	int merge(const char *name);
+	ssize_t readFullParent(char * &buf, size_t &len, off_t &offset) const;
+	ssize_t readParent(char * &buf, size_t &len, off_t &offset, off_t block_offset) const;
+	void copyFromBlock(char * &buf, size_t &len, off_t &offset, char *block, size_t block_size, off_t block_offset) const;
 
 	LinearMap	m_LinearMap;
+
+	// Length of the file as seen by the user via fuse mount point.
+	//
 	off_t		m_FileSize;
+	bool		m_FileSizeSet;
 public:
 
-	Memory(const struct stat *st);
+	Memory(const struct stat *st, const char *name);
 	~Memory();
 
 	int open(const char *name, int flags);
@@ -40,13 +46,12 @@ public:
 
 	int getattr(const char *name, struct stat *st);
 
-	ssize_t read(char *buf, size_t size, off_t offset);
+	ssize_t read(char *buf, size_t size, off_t offset) const;
 
 	ssize_t write(const char *buf, size_t size, off_t offset);
 
+	friend ostream &operator<<(ostream &os, const Memory &rMemory);
 };
 
-ostream &operator<<(ostream &os, const Memory &rMemory);
-
 #endif
 
